from typing import Literal

PlaceContent = Literal[
    'center',
    'start',
    'end',
    'between',
    'around',
    'evenly',
    'baseline',
    'stretch',
]
